
# BudgetGuard
[![codecov](https://codecov.io/gh/M-Borsuk/BudgetGuard/branch/main/graph/badge.svg?token=BudgetGuard_token_here)](https://codecov.io/gh/M-Borsuk/BudgetGuard)
[![CI](https://github.com/M-Borsuk/BudgetGuard/actions/workflows/main.yml/badge.svg)](https://github.com/M-Borsuk/BudgetGuard/actions/workflows/main.yml)

BudgetGuard created by M-Borsuk

## Install it from PyPI

```bash
pip install budgetguard
```

## Usage

```py
from budgetguard import BaseClass
from budgetguard import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m budgetguard
#or
$ budgetguard
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
